### Name: Boot.CI-methods
### Title: Bootstrap confidence intervals for ED levels
### Aliases: Boot.CI Boot.CI-methods Boot.CI,list,numeric-method
###   Boot.CI,locfit,numeric-method Boot.CI,locpoly,numeric-method
###   Boot.CI,list,missing-method Boot.CI,locfit,missing-method
###   Boot.CI,locpoly,missing-method
### Keywords: regression nonparametric smooth

### ** Examples

#Same model as discussed for the function ED
ybin=function(x){
        n=length(x)
        y=numeric(n)
        p=pnorm(x, mean=0.5, sd=0.5)
        for(i in 1:n){
        y[i]=rbinom(1,1,prob=p[i])
        }
        return(y)
}

x=seq(0,1,length.out=50)
y=ybin(x)

fit=locfit(y~lp(x,deg=1, h=0.1, nn=0))
fit2=locpoly(x,y, degree=1, bandwidth=0.1)

#For each usage of the function Boot.CI a Bootstrap confidence interval is computed

Boot.CI(list(x,y), alpha=0.5)
Boot.CI(fit,alpha=0.5)
Boot.CI(fit2,alpha=0.5)

#In this example, it is not useful to compute the Bootstrap confidence intervals close to the boundaries, since the function p is very flat
ybin=function(x){
        n=length(x)
        y=numeric(n)
        p=pnorm(x, mean=0.5, sd=0.05)
        for(i in 1:n){
        y[i]=rbinom(1,1,prob=p[i])
        }
        return(y)
}
#The following plot shows how flat the function p is at the bounds.
plot(x,pnorm(x, mean=0.5, sd=0.05), type="l")

x=seq(0,1,length.out=50)
y=ybin(x)

fit=locfit(y~lp(x,deg=1, h=0.1, nn=0))
fit2=locpoly(x,y, degree=1, bandwidth=0.1)

#For each usage of the function Boot.CI a Bootstrap confidence interval is computed and the upper and lower limits are returned followed by a warning.

Boot.CI(list(x,y), alpha=0.2)
Boot.CI(fit,alpha=0.2)
Boot.CI(fit2,alpha=0.2)




