### Name: ED
### Title: Estimate for the Effective Dose level
### Aliases: ED ED-methods ED,list,numeric-method ED,locfit,numeric-method
###   ED,locpoly,numeric-method ED,list,missing-method
###   ED,locfit,missing-method ED,locpoly,missing-method
### Keywords: regression nonparametric smooth

### ** Examples

#Function to generate data for a binary response model. The response variable has a success probability pnorm(x, mean=0.5, sd=0.5).
ybin=function(x){
        n=length(x)
        y=numeric(n)
        p=pnorm(x, mean=0.5, sd=0.5)
        for(i in 1:n){
        y[i]=rbinom(1,1,prob=p[i])
        }
        return(y)
}

x=seq(0,1,length.out=50) #the variable x presents the different dose levels
y=ybin(x)                              #y is the binary response simulated by the above function

fit=locfit(y~lp(x,deg=1, h=0.1, nn=0))   #fits a local linear estimate for the success probability using the locfit function
fit2=locpoly(x,y, degree=1, bandwidth=0.1) #fits a local linear estimate for the success probability using the locpoly function

#the effective dose level is estimated through 3 different ways.  
res=ED(list(x,y), alpha=seq(0.2,0.8, length.out=40)) #a list is used and internally the function locfit
res2=ED(fit, alpha=seq(0.2,0.8, length.out=40)) #the function ED is applied to a personally adjusted this-is-escaped-codenormal-bracket50bracket-normal object
res3=ED(fit2, alpha=seq(0.2,0.8, length.out=40)) #the function ED is applied to a personally adjusted locpoly object

#To display the results 
plot(res)
lines(res2, lty=2)
lines(res3,lty=3)
lines(pnorm(x, mean=0.5, sd=0.5), x, col="red") #adds the true effective dose levels 





